| Maintainer | ongy |
|---|---|
| Stability | testing |
| Portability | Linux |
| Safe Haskell | None |
| Language | Haskell2010 |
Monky.Outputs.Guess
Description
Documentation
Guess output based on isatty and other side of the stdout fd
monky-2.2.1.0: A system state collecting library and application
| Maintainer | ongy |
|---|---|
| Stability | testing |
| Portability | Linux |
| Safe Haskell | None |
| Language | Haskell2010 |
Monky.Outputs.Guess
Description
Guess output based on isatty and other side of the stdout fd